@@ -34,7 +34,7 @@ void DayHistory::load(QString date)
         if(group != "Cardio")
             model->appendRow(new QStandardItem(group + "/" + name + ": " + var + "Kg - " + reps + " reps"));
         else
-            model->appendRow(new QStandardItem(group + "/" + name + ": " + var + "Km" + " - " + reps));
+            model->appendRow(new QStandardItem(group + "/" + name + ": " + var + "Km - " + reps));
     }
 
 }
