@@ -8,7 +8,7 @@
 #include "xml.h"
 #include "newingredientwindow.h"
 #include "historywindow.h"
-#include <QMaemo5EditBar>
+#include "exportwindow.h"
 
 class ListWindow : public QMainWindow
 {
@@ -31,11 +31,11 @@ private:
     NewExerciseWindow *nw;
     NewProgramWindow *npw;
     NewIngredientWindow *niw;
+    ExportWindow *ew;
 
     void createActions();
     void createMenu();
 
-    QMaemo5EditBar *editBar;
 
     QAction *settingsAction;
     QAction *newExerciseAction;
@@ -43,6 +43,7 @@ private:
     QAction *exportAction;
     QAction *newIngredientAction;
     QAction *historyAction;
+    QAction *importAction;
 
     QListView *lstExercises;
     QStandardItemModel *model;
@@ -62,6 +63,7 @@ private slots:
     void showNewIngredient();
     void showHistory();
     void import();
+    void showExport();
 
 };
 
